==> haskell-sockaddr-0.0.1-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sockaddr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sockaddr
version:              0.0.1
visibility:           public
id:                   sockaddr-0.0.1-EwvBMTc7ammFNn6tbYKUt6
key:                  sockaddr-0.0.1-EwvBMTc7ammFNn6tbYKUt6
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Printing SockAddr
description:          Printing SockAddr
category:             Network
abi:                  b968a790ffe25e2a2f4675ce180a7180
exposed:              True
exposed-modules:      Network.SockAddr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sockaddr
hs-libraries:         HSsockaddr-0.0.1-EwvBMTc7ammFNn6tbYKUt6
depends:
    base-4.18.2.1 byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
    bytestring-0.11.5.3 network-3.1.4.0-DqImTC0JtBs7wAjAQOfbw6

haddock-interfaces:   /usr/share/doc/haskell-sockaddr/html/sockaddr.haddock
haddock-html:         /usr/share/doc/haskell-sockaddr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sockaddr-0.0.1-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sockaddr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sockaddr
version:              0.0.1
visibility:           public
id:                   sockaddr-0.0.1-EwM5z49fORgBQchomi1glR
key:                  sockaddr-0.0.1-EwM5z49fORgBQchomi1glR
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Printing SockAddr
description:          Printing SockAddr
category:             Network
abi:                  82842925dd5773f3babc0e29b10f4300
exposed:              True
exposed-modules:      Network.SockAddr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sockaddr
hs-libraries:         HSsockaddr-0.0.1-EwM5z49fORgBQchomi1glR
depends:
    base-4.18.2.1 byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
    bytestring-0.11.5.3 network-3.1.4.0-6jdgASXXSsi4c1a8fEUR94

haddock-interfaces:   /usr/share/doc/haskell-sockaddr/html/sockaddr.haddock
haddock-html:         /usr/share/doc/haskell-sockaddr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
